## Not Another PPO (NAPPO)

### Installation
```

    conda create -y -n nappo
    conda activate nappo
    conda install pytorch torchvision cudatoolkit=10.0 -c pytorch
    pip install git+git://github.com/openai/baselines.git
    pip install nappo

```